<?php

namespace Drupal\config_enforce_devel\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;

/**
 * Defines a settings form for the Config Enforce Devel module.
 */
class ConfigEnforceDevelSettingsForm extends ConfigFormBase {

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'config_enforce_devel_settings';
  }

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return [
      'config_enforce_devel.settings',
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $config = $this->config('config_enforce_devel.settings');
    $form['available_modules'] = [
      '#type' => 'select',
      '#title' => $this->t('Select available modules'),
      '#description' => $this->t('These modules will be available on config forms, to specify where configuration files should be written. '),
      '#options' => $this->getModuleList(),
      '#multiple' => TRUE,
      '#default_value' => $config->get('available_modules'),
    ];
    return parent::buildForm($form, $form_state);
  }

  /**
   * Return a list of modules.
   */
  protected function getModuleList() {
    $modules = [];
    $moduleHandler = \Drupal::moduleHandler();
    foreach ($moduleHandler->getModuleList() as $name => $module) {
      $modules[$name] = $moduleHandler->getName($name);
    }
    return $modules;
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $this->config('config_enforce_devel.settings')
      ->set('available_modules', $form_state->getValue('available_modules'))
      ->save();
    parent::submitForm($form, $form_state);
  }

}
